# csp symphony adapter

A [csp](https://github.com/point72/csp) adapter for [symphony](https://symphony.com)

[![Build Status](https://github.com/point72/csp-adapter-symphony/actions/workflows/build.yml/badge.svg?branch=main)](https://github.com/point72/csp-adapter-symphony/actions?query=workflow%3A%22Build+Status%22)
[![GitHub issues](https://img.shields.io/github/issues/point72/csp-adapter-symphony.svg)](https://github.com/point72/csp-adapter-symphony/issues)
[![PyPI](https://img.shields.io/pypi/l/csp-adapter-symphony.svg)](https://pypi.python.org/pypi/csp-adapter-symphony)
[![PyPI](https://img.shields.io/pypi/v/csp-adapter-symphony.svg)](https://pypi.python.org/pypi/csp-adapter-symphony)

## Features

[More information is available in our wiki](https://github.com/Point72/csp-adapter-symphony/wiki)

## Installation

Install with `pip`:

```bash
pip install csp csp-adapter-symphony
```

Install with `conda`

```bash
conda install csp csp-adapter-symphony -c conda-forge
```

## License

This software is licensed under the Apache 2.0 license. See the [LICENSE](LICENSE) file for details.
